@@ -80,7 +80,9 @@ tar_renv <- function(
     callr_function = callr_function,
     callr_arguments = callr_arguments,
     envir = envir,
-    script = script
+    script = script,
+    store = tar_config_get("store"),
+    fun = "tar_renv"
   )
   invisible()
 }
