@@ -4,12 +4,19 @@
 # which could put an unexpected and unfair burden on
 # external contributors from the open source community.
 # nocov start
-aws_s3_exists <- function(key, bucket, region = NULL, version = NULL) {
+aws_s3_exists <- function(
+  key,
+  bucket,
+  region = NULL,
+  endpoint = NULL,
+  version = NULL
+) {
   tryCatch(
     aws_s3_head_true(
       key = key,
       bucket = bucket,
       region = region,
+      endpoint = endpoint,
       version = version
     ),
     http_400 = function(condition) {
@@ -18,10 +25,14 @@ aws_s3_exists <- function(key, bucket, region = NULL, version = NULL) {
   )
 }
 
-aws_s3_head <- function(key, bucket, region = NULL, version = NULL) {
-  if (!is.null(region)) {
-    withr::local_envvar(.new = list(AWS_REGION = region))
-  }
+aws_s3_head <- function(
+  key,
+  bucket,
+  region = NULL,
+  endpoint = NULL,
+  version = NULL
+) {
+  client <- aws_s3_client(endpoint = endpoint, region = region)
   args <- list(
     Key = key,
     Bucket = bucket
@@ -29,14 +40,21 @@ aws_s3_head <- function(key, bucket, region = NULL, version = NULL) {
   if (!is.null(version)) {
     args$VersionId <- version
   }
-  do.call(what = paws::s3()$head_object, args = args)
+  do.call(what = client$head_object, args = args)
 }
 
-aws_s3_head_true <- function(key, bucket, region = NULL, version = NULL) {
+aws_s3_head_true <- function(
+  key,
+  bucket,
+  region = NULL,
+  endpoint = NULL,
+  version = NULL
+) {
   aws_s3_head(
     key = key,
     bucket = bucket,
     region = region,
+    endpoint = endpoint,
     version = version
   )
   TRUE
@@ -47,11 +65,10 @@ aws_s3_download <- function(
   key,
   bucket,
   region = NULL,
+  endpoint = NULL,
   version = NULL
 ) {
-  if (!is.null(region)) {
-    withr::local_envvar(.new = list(AWS_REGION = region))
-  }
+  client <- aws_s3_client(endpoint = endpoint, region = region)
   args <- list(
     Key = key,
     Bucket = bucket
@@ -59,8 +76,28 @@ aws_s3_download <- function(
   if (!is.null(version)) {
     args$VersionId <- version
   }
-  out <- do.call(what = paws::s3()$get_object, args = args)$Body
+  out <- do.call(what = client$get_object, args = args)$Body
   writeBin(out, con = file)
+  invisible()
+}
+
+aws_s3_delete <- function(
+  key,
+  bucket,
+  region = NULL,
+  endpoint = NULL,
+  version = NULL
+) {
+  client <- aws_s3_client(endpoint = endpoint, region = region)
+  args <- list(
+    Key = key,
+    Bucket = bucket
+  )
+  if (!is.null(version)) {
+    args$VersionId <- version
+  }
+  do.call(what = client$delete_object, args = args)
+  invisible()
 }
 
 # Copied from https://github.com/paws-r/paws/blob/main/examples/s3_multipart_upload.R # nolint
@@ -71,14 +108,12 @@ aws_s3_upload <- function(
   key,
   bucket,
   region = NULL,
+  endpoint = NULL,
   metadata = list(),
   multipart = file.size(file) > part_size,
   part_size = 5 * (2 ^ 20)
 ) {
-  if (!is.null(region)) {
-    withr::local_envvar(.new = list(AWS_REGION = region))
-  }
-  client <- paws::s3()
+  client <- aws_s3_client(endpoint = endpoint, region = region)
   if (!multipart) {
     out <- client$put_object(
       Body = readBin(file, what = "raw", n = file.size(file)),
@@ -109,6 +144,7 @@ aws_s3_upload <- function(
       file = file,
       key = key,
       bucket = bucket,
+      client = client,
       part_size = part_size,
       upload_id = multipart$UploadId
     )
@@ -119,7 +155,7 @@ aws_s3_upload <- function(
       UploadId = multipart$UploadId
     )
   }, silent = TRUE)
-  return(response)
+  response
 }
 
 # Copied from https://github.com/paws-r/paws/blob/main/examples/s3_multipart_upload.R # nolint
@@ -129,10 +165,10 @@ aws_s3_upload_parts <- function(
   file,
   key,
   bucket,
+  client,
   part_size,
   upload_id
 ) {
-  client <- paws::s3()
   file_size <- file.size(file)
   num_parts <- ceiling(file_size / part_size)
   con <- base::file(file, open = "rb")
@@ -150,6 +186,17 @@ aws_s3_upload_parts <- function(
     )
     parts <- c(parts, list(list(ETag = part_response$ETag, PartNumber = i)))
   }
-  return(parts)
+  parts
+}
+
+aws_s3_client <- function(endpoint, region) {
+  config <- list()
+  if (!is.null(endpoint)) {
+    config$endpoint <- endpoint
+  }
+  if (!is.null(region)) {
+    config$region <- region
+  }
+  paws::s3(config = config)
 }
 # nocov end
