@@ -1,37 +1,33 @@
 test_that("packages are actually loaded", {
-  # Needs sge_batchtools.tmpl (in current directory).
-  unlink("_targets", recursive = TRUE)
-  on.exit(unlink("_targets", recursive = TRUE))
+  skip_on_cran()
   skip_if_not_installed("future")
   skip_if_not_installed("future.batchtools")
-  on.exit(future::plan(future::sequential), add = TRUE)
-  future::plan(
-    future.batchtools::batchtools_sge,
-    template = "sge_batchtools.tmpl"
-  )
-  old_envir <- tar_option_get("envir")
-  on.exit(tar_option_set(envir = old_envir), add = TRUE)
-  envir <- new.env(parent = globalenv())
-  tar_option_set(envir = envir)
-  x <- tar_target_raw(
-    "x",
-    quote(tibble(x = "x")),
-    packages = "tibble"
-  )
-  pipeline <- pipeline_init(list(x))
-  out <- future_init(pipeline)
-  out$run()
-  exp <- tibble::tibble(x = "x")
-  target <- pipeline_get_target(pipeline, "x")
-  expect_equal(tar_read(x), exp)
+  # Needs sge_batchtools.tmpl (in current directory).
+  tar_destroy()
+  on.exit(tar_destroy(), add = TRUE)
+  tar_script({
+    future::plan(
+      future.batchtools::batchtools_sge,
+      template = "sge_batchtools.tmpl"
+    )
+    tar_target(
+      x,
+      tibble(x = "x"),
+      packages = "tibble"
+    )
+  })
+  tar_make_future()
+  expect_equal(tar_read(x), tibble::tibble(x = "x"))
 })
 
 test_that("nontrivial globals with custom environment", {
   skip_on_cran()
   skip_if_not_installed("future")
   skip_if_not_installed("future.batchtools")
+  tar_runtime$set_fun("tar_make_future")
+  on.exit(tar_runtime$unset_fun())
   tar_destroy()
-  on.exit(tar_destroy())
+  on.exit(tar_destroy(), add = TRUE)
   tar_script({
     future::plan(
       future.batchtools::batchtools_sge,
@@ -60,8 +56,10 @@ test_that("nontrivial globals with global environment", {
   skip_on_cran()
   skip_if_not_installed("future")
   skip_if_not_installed("future.batchtools")
+  tar_runtime$set_fun("tar_make_future")
+  on.exit(tar_runtime$unset_fun())
   tar_destroy()
-  on.exit(tar_destroy())
+  on.exit(tar_destroy(), add = TRUE)
   tar_script({
     future::plan(
       future.batchtools::batchtools_sge,
@@ -84,8 +82,13 @@ test_that("nontrivial globals with global environment", {
 
 test_that("branching plan on SGE", {
   # Needs sge_batchtools.tmpl (in current directory).
+  skip_on_cran()
+  skip_if_not_installed("future")
+  skip_if_not_installed("future.batchtools")
+  tar_runtime$set_fun("tar_make_future")
+  on.exit(tar_runtime$unset_fun())
   unlink("_targets", recursive = TRUE)
-  on.exit(unlink("_targets", recursive = TRUE))
+  on.exit(unlink("_targets", recursive = TRUE), add = TRUE)
   skip_if_not_installed("future")
   skip_if_not_installed("future.batchtools")
   on.exit(future::plan(future::sequential), add = TRUE)
@@ -136,8 +139,13 @@ test_that("branching plan on SGE", {
 
 test_that("Same with worker-side storage", {
   # Needs sge_batchtools.tmpl (in current directory).
+  skip_on_cran()
+  skip_if_not_installed("future")
+  skip_if_not_installed("future.batchtools")
+  tar_runtime$set_fun("tar_make_future")
+  on.exit(tar_runtime$unset_fun())
   unlink("_targets", recursive = TRUE)
-  on.exit(unlink("_targets", recursive = TRUE))
+  on.exit(unlink("_targets", recursive = TRUE), add = TRUE)
   skip_if_not_installed("future")
   skip_if_not_installed("future.batchtools")
   on.exit(future::plan(future::sequential), add = TRUE)
@@ -184,8 +192,13 @@ test_that("Same with worker-side storage", {
 
 test_that("future.batchtools structured resources", {
   # Needs sge_batchtools.tmpl (in current directory).
+  skip_on_cran()
+  skip_if_not_installed("future")
+  skip_if_not_installed("future.batchtools")
+  tar_runtime$set_fun("tar_make_future")
+  on.exit(tar_runtime$unset_fun())
   unlink("_targets", recursive = TRUE)
-  on.exit(unlink("_targets", recursive = TRUE))
+  on.exit(unlink("_targets", recursive = TRUE), add = TRUE)
   skip_if_not_installed("future")
   skip_if_not_installed("future.batchtools")
   tar_script({
@@ -211,8 +224,13 @@ test_that("future.batchtools structured resources", {
 
 test_that("future.batchtools unstructured resources", {
   # Needs sge_batchtools.tmpl (in current directory).
+  skip_on_cran()
+  skip_if_not_installed("future")
+  skip_if_not_installed("future.batchtools")
+  tar_runtime$set_fun("tar_make_future")
+  on.exit(tar_runtime$unset_fun())
   unlink("_targets", recursive = TRUE)
-  on.exit(unlink("_targets", recursive = TRUE))
+  on.exit(unlink("_targets", recursive = TRUE), add = TRUE)
   skip_if_not_installed("future")
   skip_if_not_installed("future.batchtools")
   tar_script({
